@@ -27,7 +27,6 @@ from awscli.customizations.s3.fileformat import FileFormat
 from awscli.customizations.s3.filegenerator import FileGenerator
 from awscli.customizations.s3.fileinfo import FileInfo
 from awscli.customizations.s3.filters import create_filter
-from awscli.customizations.s3.s3handler import S3Handler
 from awscli.customizations.s3.s3handler import S3TransferHandlerFactory
 from awscli.customizations.s3.utils import find_bucket_key, uni_print, \
     AppendFilter, find_dest_path_comp_key, human_readable_size, \
@@ -1007,15 +1006,10 @@ class CommandArchitecture(object):
                                      is_stream=True)]
         file_info_builder = FileInfoBuilder(
             self._client, self._source_client, self.parameters)
-        s3handler = S3Handler(self.session, self.parameters,
-                              runtime_config=self._runtime_config,
-                              result_queue=result_queue)
 
-        s3_transfer_handler = s3handler
-        if self.cmd in ['cp', 'rm', 'sync', 'mv']:
-            s3_transfer_handler = S3TransferHandlerFactory(
-                self.parameters, self._runtime_config)(
-                    self._client, result_queue)
+        s3_transfer_handler = S3TransferHandlerFactory(
+            self.parameters, self._runtime_config)(
+                self._client, result_queue)
 
         sync_strategies = self.choose_sync_strategies()
 
